micropip
========

micropip is a lightweight package installer for Pyodide and other projects that use Pyodide.

Overview
----------------

.. toctree::
   :maxdepth: 1

   project/usage.md
   project/api.md
   project/micropip-in-other-projects.md


Communication
-------------

- Blog: `blog.pyodide.org <https://blog.pyodide.org/>`_
- Mailing list: `mail.python.org/mailman3/lists/pyodide.python.org/ <https://mail.python.org/mailman3/lists/pyodide.python.org/>`_
- Gitter: `gitter.im/pyodide/community <https://gitter.im/pyodide/community>`_
- Twitter: `twitter.com/pyodide <https://twitter.com/pyodide>`_
- Stack Overflow: `stackoverflow.com/questions/tagged/pyodide <https://stackoverflow.com/questions/tagged/pyodide>`_
